@@ -8,6 +8,7 @@ from __future__ import absolute_import, print_function
 import sys
 
 from conda.base.context import context
+from conda.core.package_cache_data import PackageCacheData
 from conda.core.prefix_data import PrefixData
 from conda.core.solve import get_pinned_specs
 from conda.models.channel import prioritize_channels
@@ -112,7 +113,9 @@ def mamba_install(prefix, specs, args, env, *_, **kwargs):
         exit(1)
 
     package_cache = api.MultiPackageCache(context.pkgs_dirs)
-    transaction = api.Transaction(solver, package_cache)
+    transaction = api.Transaction(
+        solver, package_cache, PackageCacheData.first_writable().pkgs_dir
+    )
     if not (context.quiet or context.json):
         transaction.print()
     mmb_specs, to_link, to_unlink = transaction.to_conda()
